#
# spec file for package libcpuid
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver  14
Name:           libcpuid
Version:        0.4.0
Release:        lp151.2.3
Summary:        Provides CPU identification for x86
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            https://github.com/anrieff/libcpuid
Source0:        https://github.com/anrieff/libcpuid/releases/download/v%{version}/libcpuid-%{version}.tar.gz
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %{ix86} x86_64

%description
Libcpuid provides CPU identification for the x86 (and x86_64).

%package tools
Summary:        Tools based on %{name}
Group:          Hardware/Other

%description tools
This package provides tools based on %{name}

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{so_ver} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.
For details about the programming API, please see the docs
on the project's site (http://libcpuid.sourceforge.net/)

%package -n %{name}%{so_ver}
Summary:        Provides CPU identification for x86
Group:          System/Libraries

%description -n %{name}%{so_ver}
Libcpuid provides CPU identification for the x86 (and x86_64).

%prep
%setup -q

%build
%configure \
  --enable-static=no
make %{?_smp_mflags} V=1

%install
%make_install

# Drop useless libtool files
find %{buildroot} -type f -name "*.la" -delete -print

# Generate manpages
help2man ./cpuid_tool/cpuid_tool > cpuid_tool.1
install -D -p -m 0644 cpuid_tool.1 \
  %{buildroot}%{_mandir}/man1/cpuid_tool.1

%check
make %{?_smp_mflags} test

%post -n %{name}%{so_ver} -p /sbin/ldconfig
%postun -n %{name}%{so_ver} -p /sbin/ldconfig

%files tools
%defattr(-,root,root)
%{_bindir}/cpuid_tool
%{_mandir}/man1/cpuid_tool.1%{ext_man}

%files -n %{name}%{so_ver}
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_libdir}/%{name}.so.%{so_ver}*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Jun  8 2017 mpluskal@suse.com
- Enable internal tests
* Mon Nov 28 2016 mpluskal@suse.com
- Update to version 0.4.0:
  * A backwards-incompatible change, since the sizeof
    cpu_raw_data_t and cpu_id_t are now different.
  * Better detection of AMD clock multiplier with msrinfo.
  * Support for Intel SGX detection
- Some packaging cleanups
  * Use url as source
  * Split binary from devel package
* Sun Oct 16 2016 dap.darkness@gmail.com
- Update from 0.1.0 to 0.3.0:
  * Added intel_fn11 fields to cpu_raw_data_t to handle
    new processor topology enumeration required on Core i7
  * Support for Intel Nehalem architecture CPUs (Core i7, Xeon i7)
  * Added support for greater more accurate CPU clock measurements
    with cpu_clock_by_ic()
  * Support for AMD Bulldozer CPUs, 128-bit SSE unit size checking.
    A backwards-incompatible change, since the sizeof cpu_id_t is
    now different.
  * Support for Ivy Bridge, and detecting the presence of the
    RdRand instruction.
  * Support for newer processors up to Haswell and Vishera
  * Fix clock detection in cpu_clock_by_ic() for Bulldozer
  * Support for detection of AVX/AVX2/BMI1/BMI2
  * More entries supported in cpu_msrinfo()
  * Rename of some CPU codenames, made more consistent
  * *BSD and Solaris support (unofficial)
  * A backwards-incompatible change, since the sizeof
    cpu_raw_data_t and cpu_id_t are now different.
  * Support for processors up to Skylake.
  * Fix clock detection in cpu_clock_by_ic() for Skylake.
  * Support up to 8 subleaf entries for CPUID leaf 04 and detection
    of L4 cache.
  * MSR functions supported on FreeBSD.
  * INFO_VOLTAGE request supported by cpu_msrinfo().
* Mon Aug 18 2014 dap.darkness@gmail.com
- Updated to resolve "W: file-contains-current-date".
* Thu Jul 31 2014 dap.darkness@gmail.com
- Updated from https://github.com/anrieff/libcpuid
* Sun Feb  2 2014 dap.darkness@gmail.com
- Initial build.
